<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bn">
<context>
    <name>Category</name>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="362"/>
        <source>All Fonts</source>
        <translation>সব টাউন্সপ্রিন্ট</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="363"/>
        <source>System</source>
        <translation>সিস্টেম</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="364"/>
        <source>User</source>
        <translation>ব্যবহারকারী</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="365"/>
        <source>Favorites</source>
        <translation>পছন্দের</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="366"/>
        <source>Active</source>
        <translation>কার্যকর</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="367"/>
        <source>Chinese</source>
        <translation>চীনী</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="368"/>
        <source>Monospaced</source>
        <translation>সমান স্পেস</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="139"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>বাতিল</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="550"/>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 একটি টাউন্সপ্রিন্ট পরিবর্তন করলে তার সমস্ত টাউন্সপ্রিন্টটি মুছে দেওয়া হবে</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="544"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>মুছে দেওয়া</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="563"/>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 একটি টাউন্সপ্রিন্ট পরিবর্তন করলে তার সমস্ত টাউন্সপ্রিন্টটি সক্রিয় করা হবে</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="565"/>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 একটি টাউন্সপ্রিন্ট পরিবর্তন করলে তার সমস্ত টাউন্সপ্রিন্টটি বন্ধ করা হবে</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="576"/>
        <source>Enable</source>
        <comment>button</comment>
        <translation>সক্রিয় করাতে</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="578"/>
        <source>Disable</source>
        <comment>button</comment>
        <translation>বন্ধ করাতে</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="467"/>
        <source>Apply to all selected font families</source>
        <translation>সব নির্বাচিত টাউন্সপ্রিন্টে প্রয়োগ করা</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="480"/>
        <source>Cancel</source>
        <translation>বাতিল</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="103"/>
        <source>Broken file</source>
        <translation>ক্ষতিগ্রস্ত ফাইল</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="114"/>
        <source>Same version installed</source>
        <translation>সমান ভার্সন ইনস্টল করা হয়েছে</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="125"/>
        <source>System Font</source>
        <translation>সিস্টেম টাউন্সপ্রিন্ট</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="371"/>
        <source>Ctrl+Shift+/</source>
        <translation>ক্রোল্ট শিফ্ট ফাইর্স্টাইল্স</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="384"/>
        <source>PgUp</source>
        <translation>পাগ অপ</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="403"/>
        <source>PgDown</source>
        <translation>পাগ ডাউন</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="423"/>
        <source>Ctrl+Alt+F</source>
        <translation>ক্রোল্ট অল্ট এফ</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="441"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="521"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="326"/>
        <source>Ctrl+=</source>
        <translation>ক্রোল্ট ইক্সপ্লাসনেট</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="342"/>
        <source>Ctrl+-</source>
        <translation>ক্রোল্ট মিনিমাস</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="358"/>
        <source>Ctrl+0</source>
        <translation>ক্রোল্ট জিরো</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1654"/>
        <source>%1 font installed</source>
        <translation>%1 ফont ইনস্টল হয়েছে</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1656"/>
        <source>%1 fonts installed</source>
        <translation>%1 ফont ইনস্টল হয়েছে</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="474"/>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="562"/>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1661"/>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>%1 ফont ইনস্টল করতে সমস্যা হয়েছে। ডিস্ক স্থান অধিক নেই</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1663"/>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>%1 ফont ইনস্টল করতে সমস্যা হয়েছে। ডিস্ক স্থান অধিক নেই</translation>
    </message>
    <message>
        <location filename="../libdeepin-font-manager/dcopyfilesmanager.h" line="12"/>
        <source>Fonts</source>
        <translation>ফont</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <location filename="../libdeepin-font-manager/dfontwidget.cpp" line="127"/>
        <source>Broken file</source>
        <translation>বাটার ফাইল</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="229"/>
        <source>This font will not be available to applications</source>
        <translation>এই ফont এপ্লিকেশনের জন্য উপযোগী হবে না</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="231"/>
        <source>These fonts will not be available to applications</source>
        <translation>এই ফont এপ্লিকেশনের জন্য উপযোগী হবে না</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="234"/>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>অন্যান্য %1 সিস্টেম ফont ডিলিট করা যাবে না</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="237"/>
        <source>The font "%1" in use cannot be deleted</source>
        <translation>ইউজেড হওয়া ফont "%1" ডিলিট করা যাবে না</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="240"/>
        <source>The other %1 system fonts and the font "%2" in use cannot be deleted</source>
        <translation>অন্যান্য %1 সিস্টেম ফont এবং ইউজেড হওয়া ফont "%2" ডিলিট করা যাবে না</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="204"/>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>%1 ফont নিবন্ধন থেকে ডিলিট করতে আপনি কি সত্যি নিশ্চিত?</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="140"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>ডিলিট</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontspinnerwidget.cpp" line="74"/>
        <source>Deleting fonts, please wait...</source>
        <translation>ফont ডিলিট হচ্ছে, অপেক্ষা করুন...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="151"/>
        <source>Font Verification</source>
        <translation>ফont চেক</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="252"/>
        <source>No fonts to be installed</source>
        <translation>ইনস্টল করতে ফont নেই</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="186"/>
        <source>Exit</source>
        <translation>আসর্গ</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="187"/>
        <source>Continue</source>
        <translation>কর্তব্য</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <location filename="../libdeepin-font-manager/dfontpreviewitemdef.h" line="15"/>
        <source>Don't let your dreams be dreams</source>
        <translation>আপনার ধারণা না হয়ে থাকুন</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="131"/>
        <source>Basic info</source>
        <translation>ভিত্তিক তথ্য</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="60"/>
        <source>Style</source>
        <translation>স্টাইল</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="62"/>
        <source>Type</source>
        <translation>প্রকার</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="66"/>
        <source>Version</source>
        <translation>বৈশিষ্ট্য</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="72"/>
        <source>Description</source>
        <translation>বর্ণনা</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="73"/>
        <source>Unknown</source>
        <translation>অজানা</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="78"/>
        <source>Full name</source>
        <translation>মোট নাম</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="79"/>
        <source>Ps name</source>
        <translation>পুস্তকালয়ের নাম</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="80"/>
        <source>Trademark</source>
        <translation>বৈধতা</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="123"/>
        <source>Copyright</source>
        <translation>স্বামীতা অধিকার</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="124"/>
        <source>License Description</source>
        <translation>লিস্টেন্স বিবরণ</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../deepin-font-manager/main.cpp" line="60"/>
        <source>Font Manager</source>
        <translation>বর্ণমালা ম্যানেজার</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/main.cpp" line="61"/>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>বর্ণমালা ম্যানেজার পользоватলকে বর্ণমালা উত্সাহিত করে এবং মন্তব্য করে।</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontspinnerwidget.cpp" line="37"/>
        <source>Loading fonts, please wait...</source>
        <translation>বর্ণমালা লোড হচ্ছে, অপেক্ষা করুন...</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2093"/>
        <source>The font exported to your desktop</source>
        <translation>বর্ণমালাটি আপনার ডেস্কটপে অ্যাক্সেস করা হয়েছে</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2095"/>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 বর্ণমালা আপনার ডেস্কটপে অ্যাক্সেস করা হয়েছে</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2099"/>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>1 বর্ণমালা অ্যাক্সেস করা সম্ভব নয়। ডিস্কে অক্ষয় প্রদেশ অপরিচ্ছন্ন।</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2102"/>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>%1 বর্ণমালা অ্যাক্সেস করা সম্ভব নয়। ডিস্কে অক্ষয় প্রদেশ অপরিচ্ছন্ন।</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="63"/>
        <source>Add font</source>
        <translation>বর্ণমালা যোগ করুন</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="71"/>
        <source>Enable</source>
        <translation>নোট করুন</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="297"/>
        <source>Disable</source>
        <translation>নোট করুন</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="73"/>
        <source>Delete</source>
        <translation>Ջেলি</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="77"/>
        <source>Favorite</source>
        <translation>পছন্দ করুন</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="278"/>
        <source>Unfavorite</source>
        <translation>পছন্দ না করুন</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="80"/>
        <source>Details</source>
        <translation>বিস্তারিত</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="83"/>
        <source>Display in file manager</source>
        <translation>ফাইল ম্যানেজারে দেখান</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="75"/>
        <source>Export</source>
        <translation>অ্যাক্সেস করুন</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1875"/>
        <source>deactivated</source>
        <translation>নিactive করা হয়েছে</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1877"/>
        <source>The fonts have been deactivated</source>
        <translation>ফন্টগুলি নিactive করা হয়েছে</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1867"/>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 ব্যবহার করা হচ্ছে, তাই তা নোট করা যাবে না</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1869"/>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>সистемে ব্যবহার করা ফون্ট এবং ব্যবহার কোনো ফন্ট নিষ্পত্তি করা যাবে না</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1871"/>
        <source>You cannot disable system fonts</source>
        <translation>সিস্টেমে ব্যবহার করা ফন্ট নিষ্পত্তি করা যাবে না</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallnormalwindow.cpp" line="130"/>
        <source>Install Font</source>
        <translation>ফন্ট ইনস্টল করুন</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallnormalwindow.cpp" line="143"/>
        <source>Verifying...</source>
        <translation>যাচাই করছে...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="77"/>
        <source>Unknown</source>
        <translation>অজানা</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="206"/>
        <source>Broken file</source>
        <translation>ভেঙে ফাইল</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="227"/>
        <source>Installed</source>
        <translation>ইনস্টল করা</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="232"/>
        <source>Not Installed</source>
        <translation>ইনস্টল করা হয়নি</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="127"/>
        <source>Install Font</source>
        <translation>ফন্ট ইনস্টল করুন</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="653"/>
        <source>Search</source>
        <translation>অনুসন্ধান করুন</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="838"/>
        <source>No search results</source>
        <translation>নাই অনুসন্ধান ফলাফল</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="860"/>
        <source>No fonts</source>
        <translation>কোনো ফন্ট নাই</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2275"/>
        <source>Help</source>
        <translation>বাহ্যিক করুন</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2280"/>
        <source>Display shortcuts</source>
        <translation>শটকুর্ট প্রদর্শন করুন</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2281"/>
        <source>Page up</source>
        <translation>পাগে অপরাধ</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2282"/>
        <source>Page down</source>
        <translation>পাগে অধোরাশি</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2285"/>
        <source>Delete</source>
        <translation>পাশ করুন</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2286"/>
        <source>Add font</source>
        <translation>ফন্ট যোগ করুন</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2287"/>
        <source>Favorite</source>
        <translation>পছন্দকরুন</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2288"/>
        <source>Unfavorite</source>
        <translation>পছন্দ না করুন</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2289"/>
        <source>Font info</source>
        <translation>ফন্ট তথ্য</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="901"/>
        <source>Input preview text</source>
        <translation>প্রদর্শনী টেক্সট দাখিল করুন</translation>
    </message>
</context>
</TS>
